/* oxygen-300 - latin */
@font-face {
  font-family: 'Oxygen';
  font-style: normal;
  font-weight: 300;
  src: url("../fonts/oxygen/oxygen-v5-latin-300.eot");
  /* IE9 Compat Modes */
  src: local("Oxygen Light"), local("Oxygen-Light"), url("../fonts/oxygen/oxygen-v5-latin-300.eot?#iefix") format("embedded-opentype"), url("../fonts/oxygen/oxygen-v5-latin-300.woff2") format("woff2"), url("../fonts/oxygen/oxygen-v5-latin-300.woff") format("woff"), url("../fonts/oxygen/oxygen-v5-latin-300.ttf") format("truetype"), url("../fonts/oxygen/oxygen-v5-latin-300.svg#Oxygen") format("svg");
  /* Legacy iOS */ }

/* oxygen-regular - latin */
@font-face {
  font-family: 'Oxygen';
  font-style: normal;
  font-weight: 400;
  src: url("../fonts/oxygen/oxygen-v5-latin-regular.eot");
  /* IE9 Compat Modes */
  src: local("Oxygen"), local("Oxygen-Regular"), url("../fonts/oxygen/oxygen-v5-latin-regular.eot?#iefix") format("embedded-opentype"), url("../fonts/oxygen/oxygen-v5-latin-regular.woff2") format("woff2"), url("../fonts/oxygen/oxygen-v5-latin-regular.woff") format("woff"), url("../fonts/oxygen/oxygen-v5-latin-regular.ttf") format("truetype"), url("../fonts/oxygen/oxygen-v5-latin-regular.svg#Oxygen") format("svg");
  /* Legacy iOS */ }

/* oxygen-700 - latin */
@font-face {
  font-family: 'Oxygen';
  font-style: normal;
  font-weight: 700;
  src: url("../fonts/oxygen/oxygen-v5-latin-700.eot");
  /* IE9 Compat Modes */
  src: local("Oxygen Bold"), local("Oxygen-Bold"), url("../fonts/oxygen/oxygen-v5-latin-700.eot?#iefix") format("embedded-opentype"), url("../fonts/oxygen/oxygen-v5-latin-700.woff2") format("woff2"), url("../fonts/oxygen/oxygen-v5-latin-700.woff") format("woff"), url("../fonts/oxygen/oxygen-v5-latin-700.ttf") format("truetype"), url("../fonts/oxygen/oxygen-v5-latin-700.svg#Oxygen") format("svg");
  /* Legacy iOS */ }

/* line 46, /Users/akshay/Documents/Programming/python/bandwidth_monitor/application/server/static/scss/style.scss */
* {
  box-sizing: border-box;
  font-family: "Avenir Next","Oxygen","Helvetica" !important; }

/* line 51, /Users/akshay/Documents/Programming/python/bandwidth_monitor/application/server/static/scss/style.scss */
body {
  background-color: whitesmoke;
  height: 100vh;
  width: 100%;
  overflow: hidden; }

/* line 58, /Users/akshay/Documents/Programming/python/bandwidth_monitor/application/server/static/scss/style.scss */
.nano {
  line-height: 1.3em;
  font-size: 22px;
  color: darkslategrey;
  border-radius: 10px;
  width: 98%;
  margin: 5px auto;
  margin-top: 18px;
  height: calc(30% - 30px) !important; }

/* line 70, /Users/akshay/Documents/Programming/python/bandwidth_monitor/application/server/static/scss/style.scss */
.nano > .nano-content {
  width: 99%;
  margin: 0 auto; }

/* line 71, /Users/akshay/Documents/Programming/python/bandwidth_monitor/application/server/static/scss/style.scss */
.nano > .nano-pane {
  background: #888; }

/* line 72, /Users/akshay/Documents/Programming/python/bandwidth_monitor/application/server/static/scss/style.scss */
.nano > .nano-pane > .nano-slider {
  background: #111; }

/* line 78, /Users/akshay/Documents/Programming/python/bandwidth_monitor/application/server/static/scss/style.scss */
#charts {
  margin: 10px;
  margin-bottom: 0;
  height: calc(70% - 65px);
  min-width: 320px; }
  /* line 84, /Users/akshay/Documents/Programming/python/bandwidth_monitor/application/server/static/scss/style.scss */
  #charts div {
    border-top-left-radius: 8px !important;
    border-top-right-radius: 8px !important; }

/* line 90, /Users/akshay/Documents/Programming/python/bandwidth_monitor/application/server/static/scss/style.scss */
.container {
  height: 100vh; }

/* line 94, /Users/akshay/Documents/Programming/python/bandwidth_monitor/application/server/static/scss/style.scss */
.top-header {
  position: relative;
  height: 30px;
  width: 96%;
  margin-left: auto;
  margin-right: auto;
  margin-top: 5px;
  margin-bottom: 5px;
  color: #2c3e50; }
  /* line 105, /Users/akshay/Documents/Programming/python/bandwidth_monitor/application/server/static/scss/style.scss */
  .top-header div {
    top: 5px;
    position: absolute;
    display: inline;
    height: 30px; }
  /* line 112, /Users/akshay/Documents/Programming/python/bandwidth_monitor/application/server/static/scss/style.scss */
  .top-header .heading {
    left: 5px;
    font-size: 1.2em;
    width: 40%; }

/* line 119, /Users/akshay/Documents/Programming/python/bandwidth_monitor/application/server/static/scss/style.scss */
#highcharts-0 > svg > text {
  visibility: hidden; }

/* line 123, /Users/akshay/Documents/Programming/python/bandwidth_monitor/application/server/static/scss/style.scss */
.log {
  font-size: 0.7em;
  cursor: pointer;
  background-color: slategray;
  color: white;
  border-radius: 3px;
  margin-top: 1px;
  margin-bottom: 1px;
  height: 30px;
  width: 100%;
  white-space: nowrap;
  overflow: hidden;
  text-overflow: ellipsis;
  transition: all 0.2s ease-out;
  margin-top: 1px;
  margin-bottom: 6px; }
  /* line 138, /Users/akshay/Documents/Programming/python/bandwidth_monitor/application/server/static/scss/style.scss */
  .log.active {
    background-color: white;
    color: #2c3e50;
    /*   box-shadow: 0 0 5px 2px #fff;
        border: 1px solid #ababab;
        border-radius: 5px;
        outline: none;*/
    border: 1px solid #ababab;
    box-shadow: -1px 1px #ababab, -2px 2px #ababab, -3px 3px #ababab, -4px 4px #ababab, -5px 5px #ababab; }
  /* line 156, /Users/akshay/Documents/Programming/python/bandwidth_monitor/application/server/static/scss/style.scss */
  .log-transition {
    transition: opacity 0.5s ease; }
  /* line 159, /Users/akshay/Documents/Programming/python/bandwidth_monitor/application/server/static/scss/style.scss */
  .log-enter {
    opacity: 0; }
  /* line 162, /Users/akshay/Documents/Programming/python/bandwidth_monitor/application/server/static/scss/style.scss */
  .log-leave {
    opacity: 0;
    position: absolute;
    /* important for removal move to work */ }
  /* line 166, /Users/akshay/Documents/Programming/python/bandwidth_monitor/application/server/static/scss/style.scss */
  .log-move {
    color: red;
    transition: transform 0.5s cubic-bezier(0.55, 0, 0.1, 1);
    /* applied when moving */ }

/* line 174, /Users/akshay/Documents/Programming/python/bandwidth_monitor/application/server/static/scss/style.scss */
.info-bar {
  position: absolute;
  bottom: 0px;
  left: 2%;
  margin: 5px auto;
  width: 96%;
  height: 40px;
  color: #2c3e50; }
  /* line 184, /Users/akshay/Documents/Programming/python/bandwidth_monitor/application/server/static/scss/style.scss */
  .info-bar div {
    position: absolute;
    height: 100%;
    display: inline; }
  /* line 190, /Users/akshay/Documents/Programming/python/bandwidth_monitor/application/server/static/scss/style.scss */
  .info-bar .transfer-total {
    width: 50%; }
    /* line 192, /Users/akshay/Documents/Programming/python/bandwidth_monitor/application/server/static/scss/style.scss */
    .info-bar .transfer-total svg {
      width: 28px;
      position: absolute;
      top: 5px;
      left: 5px; }
    /* line 199, /Users/akshay/Documents/Programming/python/bandwidth_monitor/application/server/static/scss/style.scss */
    .info-bar .transfer-total .rate {
      font-size: 1.1em;
      margin-left: 40px;
      margin-top: 6px;
      width: 70%; }
    /* line 206, /Users/akshay/Documents/Programming/python/bandwidth_monitor/application/server/static/scss/style.scss */
    .info-bar .transfer-total .amount {
      color: grey;
      text-align: right;
      position: absolute;
      height: 32px;
      top: -5px;
      margin-top: 12px;
      right: 5px;
      width: calc(50% - 40px);
      border-radius: 5px; }
  /* line 219, /Users/akshay/Documents/Programming/python/bandwidth_monitor/application/server/static/scss/style.scss */
  .info-bar .up {
    top: 0;
    right: 0;
    border-top-right-radius: 5px;
    border-bottom-right-radius: 5px;
    background-color: cornsilk; }
  /* line 226, /Users/akshay/Documents/Programming/python/bandwidth_monitor/application/server/static/scss/style.scss */
  .info-bar .down {
    top: 0;
    right: 50%;
    background-color: honeydew;
    border-top-left-radius: 5px;
    border-bottom-left-radius: 5px; }

/* line 235, /Users/akshay/Documents/Programming/python/bandwidth_monitor/application/server/static/scss/style.scss */
.app {
  position: absolute;
  top: 0;
  width: 100%;
  height: 100vh; }

/* line 242, /Users/akshay/Documents/Programming/python/bandwidth_monitor/application/server/static/scss/style.scss */
.window-range-selector {
  position: absolute;
  top: 0;
  right: 3%;
  width: 180px;
  height: 40px; }
  /* line 249, /Users/akshay/Documents/Programming/python/bandwidth_monitor/application/server/static/scss/style.scss */
  .window-range-selector div {
    cursor: pointer;
    display: inline;
    position: absolute;
    height: 45px;
    width: 40px;
    top: -5px;
    border: none;
    border-bottom-left-radius: 10px;
    border-bottom-right-radius: 10px;
    color: white;
    padding-top: 15px;
    text-align: center;
    background-color: #6496c8;
    box-shadow: 0 5px #27496d; }
    /* line 265, /Users/akshay/Documents/Programming/python/bandwidth_monitor/application/server/static/scss/style.scss */
    .window-range-selector div.active {
      background-color: #417cb8;
      box-shadow: 0 5px #27496d;
      transform: translateY(5px); }
  /* line 272, /Users/akshay/Documents/Programming/python/bandwidth_monitor/application/server/static/scss/style.scss */
  .window-range-selector div:hover {
    background-color: #417cb8; }
  /* line 276, /Users/akshay/Documents/Programming/python/bandwidth_monitor/application/server/static/scss/style.scss */
  .window-range-selector .state {
    left: 0; }
    /* line 280, /Users/akshay/Documents/Programming/python/bandwidth_monitor/application/server/static/scss/style.scss */
    .window-range-selector .state svg {
      position: absolute;
      width: 90%;
      top: calc(5% + 5px);
      left: 5%; }
  /* line 288, /Users/akshay/Documents/Programming/python/bandwidth_monitor/application/server/static/scss/style.scss */
  .window-range-selector .divider {
    left: 40px;
    width: 20px;
    display: none; }
  /* line 294, /Users/akshay/Documents/Programming/python/bandwidth_monitor/application/server/static/scss/style.scss */
  .window-range-selector #range-0 {
    left: 60px; }
  /* line 298, /Users/akshay/Documents/Programming/python/bandwidth_monitor/application/server/static/scss/style.scss */
  .window-range-selector #range-5 {
    left: 100px; }
  /* line 302, /Users/akshay/Documents/Programming/python/bandwidth_monitor/application/server/static/scss/style.scss */
  .window-range-selector #range-30 {
    left: 140px; }

/*# sourceMappingURL=style.css.map */